The matrices returned by edgepoints are converted into a
list of edge points and a list of corresponding angles.
This is useful for processing the results of edgepoints
by oregMclust.
eplist(data, maxval, test = FALSE, xc = NULL, yc = NULL)list object returned from edgepoints.
positive numbers. Critical value for deciding whether a pixel belongs to an edge or not.
optional boolean. Must be set to TRUE if
edgepoints was used with estimator = "test_mean" or
estimator = "test_median". Then, maxval is the level of
the test.
optional numerical vectors defining the coordinates of
the edge points. A pixel with jump height data[[1]][i,j] gets the
coordinates (xc[i],yc[j]). By default, the coordinates are assumed as
equidistant within [0,1], e.g., for an (n x m) matrix of jump heights,
the pixel at position (i,j) gets the coordinates (i/n,j/m).
A numerical matrix. The first two columns contain the
coordinates of the pixels for which the detected jump height is
larger than maxval (or smaller than maxval if
test = TRUE). The third column contains the corresponding angles.